@@ -191,11 +191,17 @@ static int should_stack_fail(struct pf_info *pf)
  * To seed it, we use the current microseconds. To prevent seed reuse, we
  * re-seed after each fork (see atfork_child()). */
 static unsigned int randd_xn = 0xA673F42D;
+static bool randd_xn_manual = false;
 
 static void prng_seed(void)
 {
 	struct timeval tv;
 
+	/* If the seed is being handled manually, don't interfere. */
+	if (randd_xn_manual) {
+		return;
+	}
+
 	gettimeofday(&tv, NULL);
 
 	randd_xn = tv.tv_usec;
@@ -225,6 +231,8 @@ static void atfork_child(void)
  * time without clashes. */
 int fiu_init(unsigned int flags)
 {
+	char *static_seed_from_env;
+
 	/* Used to avoid re-initialization, protected by enabled_fails_lock */
 	static int initialized = 0;
 
@@ -246,6 +254,11 @@ int fiu_init(unsigned int flags)
 		return -1;
 	}
 
+	static_seed_from_env = getenv("FIU_PRNG_SEED");
+	if (static_seed_from_env != NULL) {
+		fiu_set_prng_seed(atoi(static_seed_from_env));
+	}
+
 	prng_seed();
 
 	initialized = 1;
@@ -255,6 +268,13 @@ int fiu_init(unsigned int flags)
 	return 0;
 }
 
+/* Sets the PRNG seed. */
+void fiu_set_prng_seed(unsigned int seed)
+{
+	randd_xn = seed;
+	randd_xn_manual = true;
+}
+
 /* Returns the failure status of the given name. Must work well even before
  * fiu_init() is called assuming no points of failure are enabled; although it
  * can (and does) assume fiu_init() will be called before enabling any. */
